@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 # Fact: service_provider
 #
 # Purpose: Returns the default provider Puppet will choose to manage services
@@ -12,6 +14,6 @@ require 'puppet/type/service'
 
 Facter.add(:service_provider) do
   setcode do
-    Puppet::Type.type(:service).newservice(:name => 'dummy')[:provider].to_s
+    Puppet::Type.type(:service).newservice(name: 'dummy')[:provider].to_s
   end
 end
