@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 # A method to evaluate a Facter code block if puppet is loaded.
 module Facter::Util::PuppetSettings
   # This method is intended to provide a convenient way to evaluate a
@@ -7,7 +9,7 @@ module Facter::Util::PuppetSettings
   # facter without the --puppet flag and they happen to be working in a lib
   # directory of a module.
   def self.with_puppet
-    Module.const_get('Puppet')
+    Module.const_get(:Puppet)
   rescue NameError
     nil
   else
