@@ -1,19 +1,25 @@
+# frozen_string_literal: true
+
 #
 # assert_private.rb
 #
 module Puppet::Parser::Functions
-  newfunction(:assert_private, :doc => <<-DOC
-    Sets the current class or definition as private.
-    Calling the class or definition from outside the current module will fail.
-    DOC
-             ) do |args|
+  newfunction(:assert_private, doc: <<-DOC
+    @summary
+      Sets the current class or definition as private.
 
+    @return
+      set the current class or definition as private.
+
+    Calling the class or definition from outside the current module will fail.
+  DOC
+  ) do |args|
     raise(Puppet::ParseError, "assert_private(): Wrong number of arguments given (#{args.size}}) for 0 or 1)") if args.size > 1
 
     scope = self
     if scope.lookupvar('module_name') != scope.lookupvar('caller_module_name')
       message = nil
-      if args[0] && args[0].is_a?(String)
+      if args[0].is_a?(String)
         message = args[0]
       else
         manifest_name = scope.source.name
