@@ -1,16 +1,24 @@
+# frozen_string_literal: true
+
 #
 # parseyaml.rb
 #
 module Puppet::Parser::Functions
-  newfunction(:parseyaml, :type => :rvalue, :doc => <<-DOC
-    This function accepts YAML as a string and converts it into the correct
-    Puppet structure.
+  newfunction(:parseyaml, type: :rvalue, doc: <<-DOC
+    @summary
+      This function accepts YAML as a string and converts it into the correct
+      Puppet structure.
 
-    The optional second argument can be used to pass a default value that will
-    be returned if the parsing of YAML string have failed.
+    @return
+      converted YAML into Puppet structure
+
+    > *Note:*
+      The optional second argument can be used to pass a default value that will
+      be returned if the parsing of YAML string have failed.
   DOC
-             ) do |arguments|
+  ) do |arguments|
     raise ArgumentError, 'Wrong number of arguments. 1 or 2 arguments should be provided.' unless arguments.length >= 1
+
     require 'yaml'
 
     begin
@@ -20,6 +28,7 @@ module Puppet::Parser::Functions
       # do not have Psych available.
     rescue StandardError, Psych::SyntaxError => e # rubocop:disable Lint/ShadowedException : See above
       raise e unless arguments[1]
+
       arguments[1]
     end
   end
