@@ -1,15 +1,23 @@
+# frozen_string_literal: true
+
 #
 # pry.rb
 #
 module Puppet::Parser::Functions
-  newfunction(:pry, :type => :statement, :doc => <<-DOC
-    This function invokes a pry debugging session in the current scope object. This is useful for debugging manifest code at specific points during a compilation.
+  newfunction(:pry, type: :statement, doc: <<-DOC
+    @summary
+      This function invokes a pry debugging session in the current scope object.
+    This is useful for debugging manifest code at specific points during a compilation.
 
-    *Examples:*
+    @return
+      debugging information
 
-        pry()
-    DOC
-             ) do |arguments|
+    @example **Usage**
+
+      `pry()`
+
+  DOC
+  ) do |arguments|
     begin
       require 'pry'
     rescue LoadError
@@ -23,7 +31,7 @@ module Puppet::Parser::Functions
     if $stdout.isatty
       binding.pry # rubocop:disable Lint/Debugger
     else
-      Puppet.warning 'pry(): cowardly refusing to start the debugger on a daemonized master'
+      Puppet.warning 'pry(): cowardly refusing to start the debugger on a daemonized server'
     end
   end
 end
