@@ -1,26 +1,28 @@
+# frozen_string_literal: true
+
 #
 #  swapcase.rb
 #  Please note: This function is an implementation of a Ruby class and as such may not be entirely UTF8 compatible. To ensure compatibility please use this function with Ruby 2.4.0 or greater - https://bugs.ruby-lang.org/issues/10085.
 #
 module Puppet::Parser::Functions
-  newfunction(:swapcase, :type => :rvalue, :doc => <<-DOC
-    This function will swap the existing case of a string.
+  newfunction(:swapcase, type: :rvalue, doc: <<-DOC
+    @summary
+      This function will swap the existing case of a string.
 
-    *Examples:*
+    @return
+      string with uppercase alphabetic characters converted to lowercase and lowercase characters converted to uppercase
 
-        swapcase("aBcD")
-
-    Would result in: "AbCd"
-    DOC
-             ) do |arguments|
+    @example **Usage**
 
+      swapcase("aBcD")
+      Would result in: "AbCd"
+  DOC
+  ) do |arguments|
     raise(Puppet::ParseError, "swapcase(): Wrong number of arguments given (#{arguments.size} for 1)") if arguments.empty?
 
     value = arguments[0]
 
-    unless value.is_a?(Array) || value.is_a?(String)
-      raise(Puppet::ParseError, 'swapcase(): Requires either array or string to work with')
-    end
+    raise(Puppet::ParseError, 'swapcase(): Requires either array or string to work with') unless value.is_a?(Array) || value.is_a?(String)
 
     result = if value.is_a?(Array)
                # Numbers in Puppet are often string-encoded which is troublesome ...
