@@ -1,15 +1,21 @@
+# frozen_string_literal: true
+
 #
 # to_bytes.rb
 #
 module Puppet::Parser::Functions
-  newfunction(:to_bytes, :type => :rvalue, :doc => <<-DOC
-    Converts the argument into bytes, for example 4 kB becomes 4096.
+  newfunction(:to_bytes, type: :rvalue, doc: <<-DOC
+    @summary
+        Converts the argument into bytes, for example 4 kB becomes 4096.
+
+    @return
+      converted value into bytes
+
     Takes a single string value as an argument.
     These conversions reflect a layperson's understanding of
     1 MB = 1024 KB, when in fact 1 MB = 1000 KB, and 1 MiB = 1024 KiB.
-    DOC
-             ) do |arguments|
-
+  DOC
+  ) do |arguments|
     raise(Puppet::ParseError, "to_bytes(): Wrong number of arguments given (#{arguments.size} for 1)") if arguments.size != 1
 
     arg = arguments[0]
