@@ -1,9 +1,12 @@
+# frozen_string_literal: true
+
 #
 # values_at.rb
 #
 module Puppet::Parser::Functions
-  newfunction(:values_at, :type => :rvalue, :doc => <<-DOC
-    Finds value inside an array based on location.
+  newfunction(:values_at, type: :rvalue, doc: <<-DOC
+    @summary
+      Finds value inside an array based on location.
 
     The first argument is the array you want to analyze, and the second element can
     be a combination of:
@@ -12,48 +15,45 @@ module Puppet::Parser::Functions
     * A range in the form of 'start-stop' (eg. 4-9)
     * An array combining the above
 
-    *Examples*:
+    @return
+      an array of values identified by location
 
-        values_at(['a','b','c'], 2)
+    @example **Usage**
 
-    Would return ['c'].
+      values_at(['a','b','c'], 2)
+      Would return ['c']
 
-        values_at(['a','b','c'], ["0-1"])
+      values_at(['a','b','c'], ["0-1"])
+      Would return ['a','b']
 
-    Would return ['a','b'].
+      values_at(['a','b','c','d','e'], [0, "2-3"])
+      Would return ['a','c','d']
 
-        values_at(['a','b','c','d','e'], [0, "2-3"])
-
-    Would return ['a','c','d'].
-
-    Note that since Puppet 4.0.0 it is possible to slice an array with index and count directly in the language.
+    > *Note:*
+    Since Puppet 4.0.0 it is possible to slice an array with index and count directly in the language.
     A negative value is taken to be "from the end" of the array:
 
-        ['a', 'b', 'c', 'd'][1, 2]   # results in ['b', 'c']
-        ['a', 'b', 'c', 'd'][2, -1]  # results in ['c', 'd']
-        ['a', 'b', 'c', 'd'][1, -2]  # results in ['b', 'c']
-    DOC
-             ) do |arguments|
+    `['a', 'b', 'c', 'd'][1, 2]`   results in `['b', 'c']`
+    `['a', 'b', 'c', 'd'][2, -1]`  results in `['c', 'd']`
+    `['a', 'b', 'c', 'd'][1, -2]`  results in `['b', 'c']`
 
+  DOC
+  ) do |arguments|
     raise(Puppet::ParseError, "values_at(): Wrong number of arguments given (#{arguments.size} for 2)") if arguments.size < 2
 
     array = arguments.shift
 
-    unless array.is_a?(Array)
-      raise(Puppet::ParseError, 'values_at(): Requires array to work with')
-    end
+    raise(Puppet::ParseError, 'values_at(): Requires array to work with') unless array.is_a?(Array)
 
     indices = [arguments.shift].flatten # Get them all ... Pokemon ...
 
-    if !indices || indices.empty?
-      raise(Puppet::ParseError, 'values_at(): You must provide at least one positive index to collect')
-    end
+    raise(Puppet::ParseError, 'values_at(): You must provide at least one positive index to collect') if !indices || indices.empty?
 
     indices_list = []
 
     indices.each do |i|
       i = i.to_s
-      m = i.match(%r{^(\d+)(\.\.\.?|\-)(\d+)$})
+      m = i.match(%r{^(\d+)(\.\.\.?|-)(\d+)$})
       if m
         start = m[1].to_i
         stop  = m[3].to_i
@@ -64,23 +64,19 @@ module Puppet::Parser::Functions
         raise(Puppet::ParseError, 'values_at(): Stop index in given indices range exceeds array size') if stop > array.size - 1 # First element is at index 0 is it not?
 
         range = case type
-                when %r{^(\.\.|\-)$} then (start..stop)
-                when %r{^(\.\.\.)$}  then (start...stop) # Exclusive of last element ...
+                when %r{^(\.\.|-)$} then (start..stop)
+                when %r{^(\.\.\.)$} then (start...stop) # Exclusive of last element ...
                 end
 
         range.each { |i| indices_list << i.to_i } # rubocop:disable Lint/ShadowingOuterLocalVariable : Value is meant to be shadowed
       else
         # Only positive numbers allowed in this case ...
-        unless i =~ %r{^\d+$}
-          raise(Puppet::ParseError, 'values_at(): Unknown format of given index')
-        end
+        raise(Puppet::ParseError, 'values_at(): Unknown format of given index') unless %r{^\d+$}.match?(i)
 
         # In Puppet numbers are often string-encoded ...
         i = i.to_i
 
-        if i > array.size - 1 # Same story.  First element is at index 0 ...
-          raise(Puppet::ParseError, 'values_at(): Given index exceeds array size')
-        end
+        raise(Puppet::ParseError, 'values_at(): Given index exceeds array size') if i > array.size - 1 # Same story.  First element is at index 0 ...
 
         indices_list << i
       end
